@@ -241,13 +241,6 @@ def _create_bootstrap_script(options):
     else:
         customize_source = _get_customize_source(options)
     bootstrap_source = virtualenv.create_bootstrap_script(customize_source)
-    # Patch to fix virtualenv 1.5 bug #60 on Windows.  For details see
-    # http://bitbucket.org/ianb/virtualenv/issue/60.
-    # This patch should be removed when virtualenv 1.5.1 is released.
-    bootstrap_source = bootstrap_source.replace(
-      "assert relpath[0] == '/'",
-      "assert relpath[0] == os.sep",
-    )
     script_file = open(options.script_name, 'wb')
     try:
         script_file.write(bootstrap_source)
